@@ -3,6 +3,7 @@ import oyaml as yaml
 import aidirectory.utils as utils
 import aidirectory as ai
 import simplelogging
+from aihelper import aiyaml
 
 log = simplelogging.get_logger(file_name="directory.log", console=False)
 
@@ -61,20 +62,20 @@ def main():
         with open(parameters, "r") as stream:
             data_loaded = yaml.safe_load(stream)
     except FileNotFoundError as e:
-        log(f"Unable to find the parameter file {e}")
-        data_loaded = utils.write_yaml()
+        log.warning(f"Unable to find the parameter file {e}")
+        data_loaded = aiyaml.write_directories()
         with open("parameters.yaml", "w") as outfile:
             yaml.dump(data_loaded, outfile, default_flow_style=False)
         print("Please fill out the parameter.yaml document")
         try:
             os.startfile(os.path.join(os.getcwd(), "parameters.yaml"))
         except OSError as e:
-            log(f"Unable to open the parameter file {e}")
+            log.warning(f"Unable to open the parameter file {e}")
             pass
     try:
         run(*utils.decompress(data_loaded))
     except TypeError as e:
-        log(f"An errror occured: {e}")
+        log.warning(f"An errror occured: {e}")
         print("Please double-check your parameters.yaml document'")
         try:
             os.startfile(os.path.join(os.getcwd(), "parameters.yaml"))
@@ -90,7 +91,7 @@ def main():
             cmdlet = ai.cmd()
             outfile.writelines(cmdlet)
     except FileNotFoundError as e:
-        log(f"Unable to write to the folder. Probably does not exist {e}")
+        log.warning(f"Unable to write to the folder. Probably does not exist {e}")
         pass
 
 
